summaryrefslogtreecommitdiff
path: root/src/library
diff options
context:
space:
mode:
authorMartin Odersky <odersky@gmail.com>2007-11-30 08:09:39 +0000
committerMartin Odersky <odersky@gmail.com>2007-11-30 08:09:39 +0000
commit43319c2b2c3e9769d3744b801964a3fabb56ceda (patch)
treefc195d2024ba1afafa09d6db488e8b590a54f909 /src/library
parent1d4bc5dea53fe7d7c1ed29ea03d23d90988e2d10 (diff)
downloadscala-43319c2b2c3e9769d3744b801964a3fabb56ceda.tar.gz
scala-43319c2b2c3e9769d3744b801964a3fabb56ceda.tar.bz2
scala-43319c2b2c3e9769d3744b801964a3fabb56ceda.zip
format -> formatted
Diffstat (limited to 'src/library')
-rw-r--r--src/library/scala/runtime/StringAdd.scala4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/library/scala/runtime/StringAdd.scala b/src/library/scala/runtime/StringAdd.scala
index 8591ae3313..b3cad91df5 100644
--- a/src/library/scala/runtime/StringAdd.scala
+++ b/src/library/scala/runtime/StringAdd.scala
@@ -25,12 +25,12 @@ final class StringAdd(self: Any) {
def +(other: String) = self.toString + other
/** Formats string according to given <code>format</code> string.
* Format strings are as for <code>String.format</code>
* (@see java.lang.String.format).
* Only works on Java 1.5 or higher!
*/
- def format(format: String): String = {
+ def formatted(format: String): String = {
// This should be:
// String.format(format, Array(self.asInstanceOf[Object]))
// However, the line above does not compile on Java 1.4 because String.format exists only in 1.5
@@ -25,12 +25,12 @@ final class StringAdd(self: Any) {
def +(other: String) = self.toString + other
- /** Formats string according to given <code>format</code> string.
+ /** Returns string formatted according to given <code>format</code> string.
* Format strings are as for <code>String.format</code>
* (@see java.lang.String.format).